summaryrefslogtreecommitdiff
path: root/gdk/x11/gdkmain-x11.c
diff options
context:
space:
mode:
Diffstat (limited to 'gdk/x11/gdkmain-x11.c')
-rw-r--r--gdk/x11/gdkmain-x11.c32
1 files changed, 16 insertions, 16 deletions
diff --git a/gdk/x11/gdkmain-x11.c b/gdk/x11/gdkmain-x11.c
index 72edfe1c09..4fe1d36b19 100644
--- a/gdk/x11/gdkmain-x11.c
+++ b/gdk/x11/gdkmain-x11.c
@@ -102,7 +102,7 @@ static int gdk_x_error (Display *display,
static int gdk_x_io_error (Display *display);
void
-_gdk_x11_windowing_init (void)
+_gdk_x11_surfaceing_init (void)
{
XSetErrorHandler (gdk_x_error);
XSetIOErrorHandler (gdk_x_io_error);
@@ -130,20 +130,20 @@ _gdk_x11_convert_grab_status (gint status)
}
/*
- * _gdk_x11_window_grab_check_unmap:
- * @window: a #GdkWindow
+ * _gdk_x11_surface_grab_check_unmap:
+ * @surface: a #GdkSurface
* @serial: serial from Unmap event (or from NextRequest(display)
* if the unmap is being done by this client.)
*
* Checks to see if an unmap request or event causes the current
* grab window to become not viewable, and if so, clear the
* the pointer we keep to it.
**/
void
-_gdk_x11_window_grab_check_unmap (GdkWindow *window,
+_gdk_x11_surface_grab_check_unmap (GdkSurface *surface,
gulong serial)
{
- GdkDisplay *display = gdk_window_get_display (window);
+ GdkDisplay *display = gdk_surface_get_display (surface);
GdkSeat *seat;
GList *devices, *d;
@@ -153,24 +153,24 @@ _gdk_x11_window_grab_check_unmap (GdkWindow *window,
devices = g_list_prepend (devices, gdk_seat_get_keyboard (seat));
devices = g_list_prepend (devices, gdk_seat_get_pointer (seat));
/* End all grabs on the newly hidden window */
for (d = devices; d; d = d->next)
- _gdk_display_end_device_grab (display, d->data, serial, window, TRUE);
+ _gdk_display_end_device_grab (display, d->data, serial, surface, TRUE);
g_list_free (devices);
}
/*
- * _gdk_x11_window_grab_check_destroy:
- * @window: a #GdkWindow
+ * _gdk_x11_surface_grab_check_destroy:
+ * @surface: a #GdkSurface
*
* Checks to see if window is the current grab window, and if
* so, clear the current grab window.
**/
void
-_gdk_x11_window_grab_check_destroy (GdkWindow *window)
+_gdk_x11_surface_grab_check_destroy (GdkSurface *surface)
{
- GdkDisplay *display = gdk_window_get_display (window);
+ GdkDisplay *display = gdk_surface_get_display (surface);
GdkSeat *seat;
GdkDeviceGrabInfo *grab;
GList *devices, *d;
@@ -183,10 +183,10 @@ _gdk_x11_window_grab_check_destroy (GdkWindow *window)
for (d = devices; d; d = d->next)
{
/* Make sure there is no lasting grab in this native window */
grab = _gdk_display_get_last_device_grab (display, d->data);
- if (grab && grab->native_window == window)
+ if (grab && grab->native_surface == surface)
{
/* We don't know the actual serial to end, but it
doesn't really matter as this only happens
@@ -130,20 +130,20 @@ _gdk_x11_convert_grab_status (gint status)
*
* Checks to see if an unmap request or event causes the current
- * grab window to become not viewable, and if so, clear the
+ * grab surface to become not viewable, and if so, clear the
* the pointer we keep to it.
**/
@@ -153,24 +153,24 @@ _gdk_x11_window_grab_check_unmap (GdkWindow *window,
devices = g_list_prepend (devices, gdk_seat_get_keyboard (seat));
devices = g_list_prepend (devices, gdk_seat_get_pointer (seat));
- /* End all grabs on the newly hidden window */
+ /* End all grabs on the newly hidden surface */
for (d = devices; d; d = d->next)
@@ -153,24 +153,24 @@ _gdk_x11_window_grab_check_unmap (GdkWindow *window,
*
- * Checks to see if window is the current grab window, and if
- * so, clear the current grab window.
+ * Checks to see if surface is the current grab surface, and if
+ * so, clear the current grab surface.
**/
void
@@ -183,10 +183,10 @@ _gdk_x11_window_grab_check_destroy (GdkWindow *window)
for (d = devices; d; d = d->next)
{
- /* Make sure there is no lasting grab in this native window */
+ /* Make sure there is no lasting grab in this native surface */
grab = _gdk_display_get_last_device_grab (display, d->data);